==> hudder-8.0.8-sources.jar: io/github/ngspace/hudder/v2runtime/methods/ItemStackMethods.java <==
package io.github.ngspace.hudder.v2runtime.methods;

import io.github.ngspace.hudder.compilers.abstractions.ATextCompiler;
import io.github.ngspace.hudder.compilers.utils.CompileException;
import io.github.ngspace.hudder.compilers.utils.CompileState;
import io.github.ngspace.hudder.main.config.HudderConfig;
import io.github.ngspace.hudder.uielements.ItemElement;
import io.github.ngspace.hudder.utils.ObjectWrapper;
import net.minecraft.class_1661;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_7923;

public class ItemStackMethods implements IMethod {
	
	protected static class_310 mc = class_310.method_1551();
	@Override
	public void invoke(HudderConfig ci, CompileState meta, ATextCompiler comp, String type, int line, int charpos, ObjectWrapper... args) throws CompileException {
		int offset = "slot".equals(type)||"item".equals(type) ? 1:0;
		if (args.length<2+offset) {
			throw new CompileException("\""+type+"\" only accepts ;"+type
				+("slot".equals(type)?",[slot]":"")
				+("item".equals(type)?",[item]":"")
				+",[x],[y],<scale>,<show count>;", line, charpos);
		}
		double x = args[0+offset].asDouble();
		double y = args[1+offset].asDouble();
		float scale = (float)(args.length>2+offset?args[2+offset].asDouble():ci.scale);

		boolean showcount = args.length<=3+offset || args[3+offset].asBoolean();
		
		class_1661 inv = mc.field_1724.method_31548();
		class_1799 stack = switch (type) {
			case "hand","selectedslot": yield inv.method_5438(inv.field_7545);
			case "helmet", "hat": yield inv.method_7372(3);
			case "chestplate": yield inv.method_7372(2);
			case "pants", "leggings": yield inv.method_7372(1);
			case "boots": yield inv.method_7372(0);
			case "offhand": yield inv.field_7544.get(0);
			case "slot": yield inv.method_5438(args[0].asInt());
			case "item": yield new class_1799(class_7923.field_41178.method_63535(class_2960.method_12829(args[0].asString())));
			default: throw new IllegalArgumentException("Unexpected value: " + type);
		};
		meta.elements.add(new ItemElement(x, y, stack, scale, showcount));
	}
}

==> hudder-8.4.1-sources.jar: io/github/ngspace/hudder/v2runtime/methods/ItemStackMethods.java <==
package io.github.ngspace.hudder.v2runtime.methods;

import io.github.ngspace.hudder.compilers.abstractions.ATextCompiler;
import io.github.ngspace.hudder.compilers.utils.CompileException;
import io.github.ngspace.hudder.compilers.utils.CompileState;
import io.github.ngspace.hudder.main.config.HudderConfig;
import io.github.ngspace.hudder.uielements.ItemElement;
import io.github.ngspace.hudder.utils.ObjectWrapper;
import net.minecraft.class_1661;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_7923;

public class ItemStackMethods implements IMethod {
	
	protected static class_310 mc = class_310.method_1551();
	@Override
	public void invoke(HudderConfig ci, CompileState meta, ATextCompiler comp, String type, int line, int charpos, ObjectWrapper... args) throws CompileException {
		int offset = "slot".equals(type)||"item".equals(type) ? 1:0;
		if (args.length<2+offset) {
			throw new CompileException("\""+type+"\" only accepts ;"+type
				+("slot".equals(type)?",[slot]":"")
				+("item".equals(type)?",[item]":"")
				+",[x],[y],<scale>,<show count>;", line, charpos);
		}
		double x = args[0+offset].asDouble();
		double y = args[1+offset].asDouble();
		float scale = (float)(args.length>2+offset?args[2+offset].asDouble():ci.scale);

		boolean showcount = args.length<=3+offset || args[3+offset].asBoolean();
		
		class_1661 inv = mc.field_1724.method_31548();
		
		class_1799 stack = switch (type) {
			case "hand","selectedslot": yield inv.method_5438(inv.method_67532());
			case "helmet", "hat": yield inv.method_5438(39);
			case "chestplate": yield inv.method_5438(38);
			case "pants", "leggings": yield inv.method_5438(37);
			case "boots": yield inv.method_5438(36);
			case "offhand": yield mc.field_1724.method_6079();
			case "slot": yield inv.method_5438(args[0].asInt());
			case "item": yield new class_1799(class_7923.field_41178.method_63535(class_2960.method_12829(args[0].asString())));
			default: throw new IllegalArgumentException("Unexpected value: " + type);
		};
		meta.elements.add(new ItemElement(x, y, stack, scale, showcount));
	}
}
